package com.guwan.backend.util;

import java.lang.reflect.Field;

public class DtoGeneratorUtil {
    
    public static String generateDtoConstructor(Class<?> dtoClass) {
        StringBuilder sb = new StringBuilder();
        Field[] fields = dtoClass.getDeclaredFields();
        
        // 构造函数参数
        sb.append("public ").append(dtoClass.getSimpleName())
          .append("(");
        for (int i = 0; i < fields.length; i++) {
            if (i > 0) sb.append(", ");
            sb.append("Object ").append(fields[i].getName());
        }
        sb.append(") {\n");
        
        // 构造函数体
        for (Field field : fields) {
            String fieldName = field.getName();
            String conversion = getConversion(field.getType(), fieldName);
            sb.append("    this.").append(fieldName)
              .append(" = ").append(fieldName).append(" != null ? ")
              .append(conversion).append(" : null;\n");
        }
        
        sb.append("}");
        return sb.toString();
    }

    private static String getConversion(Class<?> type, String fieldName) {
        if (type == String.class) {
            return "String.valueOf(" + fieldName + ")";
        } else if (type == Long.class || type == long.class) {
            return "Long.valueOf(" + fieldName + ".toString())";
        } else if (type == Integer.class || type == int.class) {
            return "Integer.valueOf(" + fieldName + ".toString())";
        } else if (type == Double.class || type == double.class) {
            return "Double.valueOf(" + fieldName + ".toString())";
        } else if (type == Boolean.class || type == boolean.class) {
            return "Boolean.valueOf(" + fieldName + ".toString())";
        } else if (type == java.util.Date.class) {
            return "(" + fieldName + " instanceof java.util.Date) ? (" +
                    "java.util.Date) " + fieldName + " : new java.text.SimpleDateFormat(\"yyyy-MM-dd\").parse(" +
                    fieldName + ".toString())";
        } else if (type == java.time.LocalDate.class) {
            return "java.time.LocalDate.parse(" + fieldName + ".toString())";
        } else if (type == java.time.LocalDateTime.class) {
            return "java.time.LocalDateTime.parse(" + fieldName + ".toString())";
        } else {
            // 对于其它复杂类型，可能需要更特殊的处理
            return "(" + type.getSimpleName() + ") " + fieldName;
        }
    }
}